% This batch script analyses the "resting state" dataset
% available from the SPM website using a seed based correlation analysis:
% http://www.fil.ion.ucl.ac.uk/spm/data/spDCM/

% three different seeds in the PCC are extracted and separately entered
% into a GLM.

% Sandra Iglesias
% 18-10-2016, with many thanks to Guillaume Flandin & Darren Gitelman 
% providing the ppi_spm12_batch.m

% Directory containing the resting state data
%--------------------------------------------------------------------------
data_path = fileparts(mfilename('fullpath'));
if isempty(data_path), data_path = pwd; end
fprintf('%-40s:', 'Downloading resting state dataset...');
urlwrite('http://www.fil.ion.ucl.ac.uk/spm/data/spDCM/spDCM.zip','spDCM.zip');
unzip(fullfile(data_path,'spDCM.zip'));
data_path = fullfile(data_path,'spDCM');
fprintf(' %30s\n', '...done');

% Initialise SPM
%--------------------------------------------------------------------------
% spm('Defaults','fMRI');
% spm_jobman('initcfg');
% spm_get_defaults('cmdline',true);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% GLM SPECIFICATION, ESTIMATION, INFERENCE, RESULTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear matlabbatch

% OUTPUT DIRECTORY
%==========================================================================
matlabbatch{1}.cfg_basicio.file_dir.dir_ops.cfg_mkdir.parent = cellstr(data_path);
matlabbatch{1}.cfg_basicio.file_dir.dir_ops.cfg_mkdir.name = 'GLM1';

% MODEL SPECIFICATION
%==========================================================================

% Directory
%-----------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.dir = cellstr(fullfile(data_path,'GLM1'));

% Timing
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.timing.units = 'scans';
matlabbatch{2}.spm.stats.fmri_spec.timing.RT = 3.22;

% Session
%--------------------------------------------------------------------------
f = spm_select('FPList', fullfile(data_path,'func'), '^swrest.*\.img$');
matlabbatch{2}.spm.stats.fmri_spec.sess.scans = cellstr(f);

% Session
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.sess.cond = struct('name', {}, 'onset', {}, 'duration', {}, 'tmod', {}, 'pmod', {}, 'orth', {});
matlabbatch{2}.spm.stats.fmri_spec.sess.multi = {''};
matlabbatch{2}.spm.stats.fmri_spec.sess.regress = struct('name', {}, 'val', {});
matlabbatch{2}.spm.stats.fmri_spec.sess.multi_reg = {''};

% High-pass filter
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.sess.hpf = 128;
matlabbatch{2}.spm.stats.fmri_spec.fact = struct('name', {}, 'levels', {});
matlabbatch{2}.spm.stats.fmri_spec.bases.hrf.derivs = [0 0];
matlabbatch{2}.spm.stats.fmri_spec.volt = 1;
matlabbatch{2}.spm.stats.fmri_spec.global = 'None';
matlabbatch{2}.spm.stats.fmri_spec.mthresh = 0.8;
matlabbatch{2}.spm.stats.fmri_spec.mask = {''};
matlabbatch{2}.spm.stats.fmri_spec.cvi = 'none';

% MODEL ESTIMATION
%--------------------------------------------------------------------------
matlabbatch{3}.spm.stats.fmri_est.spmmat = cellstr(fullfile(data_path,'GLM1','SPM.mat'));
matlabbatch{3}.spm.stats.fmri_est.write_residuals = 0;
matlabbatch{3}.spm.stats.fmri_est.method.Classical = 1;

% INFERENCE
%==========================================================================
matlabbatch{4}.spm.stats.con.spmmat(1) = cellstr(fullfile(data_path,'GLM1','SPM.mat'));
matlabbatch{4}.spm.stats.con.consess{1}.tcon.name = 'Mean';
matlabbatch{4}.spm.stats.con.consess{1}.tcon.weights = 1;
matlabbatch{4}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
matlabbatch{4}.spm.stats.con.delete = 0;


% VOI extraction PCC
%==========================================================================
matlabbatch{5}.spm.util.voi.spmmat(1) = cellstr(fullfile(data_path,'GLM1','SPM.mat'));
matlabbatch{5}.spm.util.voi.adjust = 0;
matlabbatch{5}.spm.util.voi.session = 1;
matlabbatch{5}.spm.util.voi.name = 'PCC_1';
matlabbatch{5}.spm.util.voi.roi{1}.sphere.centre = [-2 -40 38];
matlabbatch{5}.spm.util.voi.roi{1}.sphere.radius = 3;
matlabbatch{5}.spm.util.voi.roi{1}.sphere.move.fixed = 1;
matlabbatch{5}.spm.util.voi.expression = 'i1';

% VOI extraction noise (CSF and WM)
%==========================================================================
matlabbatch{6}.spm.util.voi.spmmat(1) = cellstr(fullfile(data_path,'GLM1','SPM.mat'));
matlabbatch{6}.spm.util.voi.adjust = 0;
matlabbatch{6}.spm.util.voi.session = 1;
matlabbatch{6}.spm.util.voi.name = 'CSF';
matlabbatch{6}.spm.util.voi.roi{1}.sphere.centre = [16 -34 16];
matlabbatch{6}.spm.util.voi.roi{1}.sphere.radius = 3;
matlabbatch{6}.spm.util.voi.roi{1}.sphere.move.fixed = 1;
matlabbatch{6}.spm.util.voi.expression = 'i1';

matlabbatch{7}.spm.util.voi.spmmat(1) = cellstr(fullfile(data_path,'GLM1','SPM.mat'));
matlabbatch{7}.spm.util.voi.adjust = 0;
matlabbatch{7}.spm.util.voi.session = 1;
matlabbatch{7}.spm.util.voi.name = 'WM';
matlabbatch{7}.spm.util.voi.roi{1}.sphere.centre = [-28 -24 30];
matlabbatch{7}.spm.util.voi.roi{1}.sphere.radius = 3;
matlabbatch{7}.spm.util.voi.roi{1}.sphere.move.fixed = 1;
matlabbatch{7}.spm.util.voi.expression = 'i1';

% VOI extraction additional seeds in PCC
%==========================================================================
matlabbatch{8}.spm.util.voi.spmmat(1) = cellstr(fullfile(data_path,'GLM1','SPM.mat'));
matlabbatch{8}.spm.util.voi.adjust = 0;
matlabbatch{8}.spm.util.voi.session = 1;
matlabbatch{8}.spm.util.voi.name = 'PCC_2';
matlabbatch{8}.spm.util.voi.roi{1}.sphere.centre = [-2 -36 37];
matlabbatch{8}.spm.util.voi.roi{1}.sphere.radius = 3;
matlabbatch{8}.spm.util.voi.roi{1}.sphere.move.fixed = 1;
matlabbatch{8}.spm.util.voi.expression = 'i1';

matlabbatch{9}.spm.util.voi.spmmat(1) = cellstr(fullfile(data_path,'GLM1','SPM.mat'));
matlabbatch{9}.spm.util.voi.adjust = 0;
matlabbatch{9}.spm.util.voi.session = 1;
matlabbatch{9}.spm.util.voi.name = 'PCC_3';
matlabbatch{9}.spm.util.voi.roi{1}.sphere.centre = [0 -53 26];
matlabbatch{9}.spm.util.voi.roi{1}.sphere.radius = 3;
matlabbatch{9}.spm.util.voi.roi{1}.sphere.move.fixed = 1;
matlabbatch{9}.spm.util.voi.expression = 'i1';


spm_jobman('run',matlabbatch);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functional connectivity analysis with seed region PCC_1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear matlabbatch

% OUTPUT DIRECTORY
%==========================================================================
matlabbatch{1}.cfg_basicio.file_dir.dir_ops.cfg_mkdir.parent = cellstr(data_path);
matlabbatch{1}.cfg_basicio.file_dir.dir_ops.cfg_mkdir.name = 'GLM_PCC1';

% MODEL SPECIFICATION
%==========================================================================

% Directory
%-----------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.dir = cellstr(fullfile(data_path,'GLM_PCC1'));

% Timing
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.timing.units = 'scans';
matlabbatch{2}.spm.stats.fmri_spec.timing.RT = 3.22;

% Session
%--------------------------------------------------------------------------
f = spm_select('FPList', fullfile(data_path,'func'), '^swrest.*\.img$');
matlabbatch{2}.spm.stats.fmri_spec.sess.scans = cellstr(f);

% Multiple regressors: PCC_1 time series and physilogical noise
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.sess.multi_reg = {
                                                     [(fullfile(data_path,'\GLM1\VOI_PCC_1_1.mat'))]
                                                     [(fullfile(data_path,'\GLM1\VOI_CSF_1.mat'))]
                                                     [(fullfile(data_path,'\GLM1\VOI_WM_1.mat'))]
                                                     [(fullfile(data_path,'\glm\rp_rest0000.txt'))]
                                                      };
% High-pass filter
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.sess.hpf = 128;
matlabbatch{2}.spm.stats.fmri_spec.fact = struct('name', {}, 'levels', {});
matlabbatch{2}.spm.stats.fmri_spec.bases.hrf.derivs = [0 0];
matlabbatch{2}.spm.stats.fmri_spec.volt = 1;
matlabbatch{2}.spm.stats.fmri_spec.global = 'None';
matlabbatch{2}.spm.stats.fmri_spec.mthresh = 0.8;
matlabbatch{2}.spm.stats.fmri_spec.mask = {''};
matlabbatch{2}.spm.stats.fmri_spec.cvi = 'none';

% MODEL ESTIMATION
%--------------------------------------------------------------------------
matlabbatch{3}.spm.stats.fmri_est.spmmat = cellstr(fullfile(data_path,'GLM_PCC1','SPM.mat'));
matlabbatch{3}.spm.stats.fmri_est.write_residuals = 0;
matlabbatch{3}.spm.stats.fmri_est.method.Classical = 1;

% INFERENCE
%==========================================================================
matlabbatch{4}.spm.stats.con.spmmat(1) = cellstr(fullfile(data_path,'GLM_PCC1','SPM.mat'));
matlabbatch{4}.spm.stats.con.consess{1}.tcon.name = 'PCC_1';
matlabbatch{4}.spm.stats.con.consess{1}.tcon.weights = 1;
matlabbatch{4}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
matlabbatch{4}.spm.stats.con.delete = 0;

% RESULTS
%==========================================================================
% matlabbatch{5}.spm.stats.results.spmmat(1) = cellstr(fullfile(data_path,'GLM_PCC1','SPM.mat'));
% matlabbatch{5}.spm.stats.results.conspec.titlestr = '';
% matlabbatch{5}.spm.stats.results.conspec.contrasts = 1;
% matlabbatch{5}.spm.stats.results.conspec.threshdesc = 'FWE';
% matlabbatch{5}.spm.stats.results.conspec.thresh = 0.05;
% matlabbatch{5}.spm.stats.results.conspec.extent = 0;
% matlabbatch{5}.spm.stats.results.conspec.conjunction = 1;
% matlabbatch{5}.spm.stats.results.conspec.mask.none = 1;
% matlabbatch{5}.spm.stats.results.units = 1;
% matlabbatch{5}.spm.stats.results.print = 'ps';
% matlabbatch{5}.spm.stats.results.write.none = 1;


spm_jobman('run',matlabbatch);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functional connectivity analysis with seed region PCC_2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear matlabbatch

% OUTPUT DIRECTORY
%==========================================================================
matlabbatch{1}.cfg_basicio.file_dir.dir_ops.cfg_mkdir.parent = cellstr(data_path);
matlabbatch{1}.cfg_basicio.file_dir.dir_ops.cfg_mkdir.name = 'GLM_PCC2';

% MODEL SPECIFICATION
%==========================================================================

% Directory
%-----------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.dir = cellstr(fullfile(data_path,'GLM_PCC2'));

% Timing
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.timing.units = 'scans';
matlabbatch{2}.spm.stats.fmri_spec.timing.RT = 3.22;

% Session
%--------------------------------------------------------------------------
f = spm_select('FPList', fullfile(data_path,'func'), '^swrest.*\.img$');
matlabbatch{2}.spm.stats.fmri_spec.sess.scans = cellstr(f);

% Multiple regressors: PCC_1 time series and physilogical noise
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.sess.multi_reg = {
                                                     [(fullfile(data_path,'\GLM1\VOI_PCC_2_1.mat'))]
                                                     [(fullfile(data_path,'\GLM1\VOI_CSF_1.mat'))]
                                                     [(fullfile(data_path,'\GLM1\VOI_WM_1.mat'))]
                                                     [(fullfile(data_path,'\glm\rp_rest0000.txt'))]
                                                      };
% High-pass filter
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.sess.hpf = 128;
matlabbatch{2}.spm.stats.fmri_spec.fact = struct('name', {}, 'levels', {});
matlabbatch{2}.spm.stats.fmri_spec.bases.hrf.derivs = [0 0];
matlabbatch{2}.spm.stats.fmri_spec.volt = 1;
matlabbatch{2}.spm.stats.fmri_spec.global = 'None';
matlabbatch{2}.spm.stats.fmri_spec.mthresh = 0.8;
matlabbatch{2}.spm.stats.fmri_spec.mask = {''};
matlabbatch{2}.spm.stats.fmri_spec.cvi = 'none';

% MODEL ESTIMATION
%--------------------------------------------------------------------------
matlabbatch{3}.spm.stats.fmri_est.spmmat = cellstr(fullfile(data_path,'GLM_PCC2','SPM.mat'));
matlabbatch{3}.spm.stats.fmri_est.write_residuals = 0;
matlabbatch{3}.spm.stats.fmri_est.method.Classical = 1;

% INFERENCE
%==========================================================================
matlabbatch{4}.spm.stats.con.spmmat(1) = cellstr(fullfile(data_path,'GLM_PCC2','SPM.mat'));
matlabbatch{4}.spm.stats.con.consess{1}.tcon.name = 'PCC_2';
matlabbatch{4}.spm.stats.con.consess{1}.tcon.weights = 1;
matlabbatch{4}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
matlabbatch{4}.spm.stats.con.delete = 0;

% RESULTS
%==========================================================================
% matlabbatch{5}.spm.stats.results.spmmat(1) = cellstr(fullfile(data_path,'GLM_PCC2','SPM.mat'));
% matlabbatch{5}.spm.stats.results.conspec.titlestr = '';
% matlabbatch{5}.spm.stats.results.conspec.contrasts = 1;
% matlabbatch{5}.spm.stats.results.conspec.threshdesc = 'FWE';
% matlabbatch{5}.spm.stats.results.conspec.thresh = 0.05;
% matlabbatch{5}.spm.stats.results.conspec.extent = 0;
% matlabbatch{5}.spm.stats.results.conspec.conjunction = 1;
% matlabbatch{5}.spm.stats.results.conspec.mask.none = 1;
% matlabbatch{5}.spm.stats.results.units = 1;
% matlabbatch{5}.spm.stats.results.print = 'ps';
% matlabbatch{5}.spm.stats.results.write.none = 1;


spm_jobman('run',matlabbatch);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functional connectivity analysis with seed region PCC_3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear matlabbatch

% OUTPUT DIRECTORY
%==========================================================================
matlabbatch{1}.cfg_basicio.file_dir.dir_ops.cfg_mkdir.parent = cellstr(data_path);
matlabbatch{1}.cfg_basicio.file_dir.dir_ops.cfg_mkdir.name = 'GLM_PCC3';

% MODEL SPECIFICATION
%==========================================================================

% Directory
%-----------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.dir = cellstr(fullfile(data_path,'GLM_PCC3'));

% Timing
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.timing.units = 'scans';
matlabbatch{2}.spm.stats.fmri_spec.timing.RT = 3.22;

% Session
%--------------------------------------------------------------------------
f = spm_select('FPList', fullfile(data_path,'func'), '^swrest.*\.img$');
matlabbatch{2}.spm.stats.fmri_spec.sess.scans = cellstr(f);

% Multiple regressors: PCC_1 time series and physilogical noise
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.sess.multi_reg = {
                                                     [(fullfile(data_path,'\GLM1\VOI_PCC_3_1.mat'))]
                                                     [(fullfile(data_path,'\GLM1\VOI_CSF_1.mat'))]
                                                     [(fullfile(data_path,'\GLM1\VOI_WM_1.mat'))]
                                                     [(fullfile(data_path,'\glm\rp_rest0000.txt'))]
                                                      };
% High-pass filter
%--------------------------------------------------------------------------
matlabbatch{2}.spm.stats.fmri_spec.sess.hpf = 128;
matlabbatch{2}.spm.stats.fmri_spec.fact = struct('name', {}, 'levels', {});
matlabbatch{2}.spm.stats.fmri_spec.bases.hrf.derivs = [0 0];
matlabbatch{2}.spm.stats.fmri_spec.volt = 1;
matlabbatch{2}.spm.stats.fmri_spec.global = 'None';
matlabbatch{2}.spm.stats.fmri_spec.mthresh = 0.8;
matlabbatch{2}.spm.stats.fmri_spec.mask = {''};
matlabbatch{2}.spm.stats.fmri_spec.cvi = 'none';

% MODEL ESTIMATION
%--------------------------------------------------------------------------
matlabbatch{3}.spm.stats.fmri_est.spmmat = cellstr(fullfile(data_path,'GLM_PCC3','SPM.mat'));
matlabbatch{3}.spm.stats.fmri_est.write_residuals = 0;
matlabbatch{3}.spm.stats.fmri_est.method.Classical = 1;

% INFERENCE
%==========================================================================
matlabbatch{4}.spm.stats.con.spmmat(1) = cellstr(fullfile(data_path,'GLM_PCC3','SPM.mat'));
matlabbatch{4}.spm.stats.con.consess{1}.tcon.name = 'PCC_3';
matlabbatch{4}.spm.stats.con.consess{1}.tcon.weights = 1;
matlabbatch{4}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
matlabbatch{4}.spm.stats.con.delete = 0;

% RESULTS
%==========================================================================
% matlabbatch{5}.spm.stats.results.spmmat(1) = cellstr(fullfile(data_path,'GLM_PCC3','SPM.mat'));
% matlabbatch{5}.spm.stats.results.conspec.titlestr = '';
% matlabbatch{5}.spm.stats.results.conspec.contrasts = 1;
% matlabbatch{5}.spm.stats.results.conspec.threshdesc = 'FWE';
% matlabbatch{5}.spm.stats.results.conspec.thresh = 0.05;
% matlabbatch{5}.spm.stats.results.conspec.extent = 0;
% matlabbatch{5}.spm.stats.results.conspec.conjunction = 1;
% matlabbatch{5}.spm.stats.results.conspec.mask.none = 1;
% matlabbatch{5}.spm.stats.results.units = 1;
% matlabbatch{5}.spm.stats.results.print = 'ps';
% matlabbatch{5}.spm.stats.results.write.none = 1;

spm_jobman('run',matlabbatch);

